@@ -33,6 +33,9 @@ def run_tests(test_path, path_type='file'):
         should have the same format (see next parameter)
       - path_type: either 'file' (test_path refers then to files/folders) or
         'module' (test_path refers then to modules)
+
+    Output:
+      - (bool) True if pytest run correctly, False otherwise
     """
     command = [sys.executable, "-m", "pytest", 
                 "--quiet", "--color=no", "-W ignore:numpy.ufunc size changed"]
@@ -45,7 +48,11 @@ def run_tests(test_path, path_type='file'):
     else:
         raise ValueError("Input should be string or list of strings")
     logging.info(f"Run tests: {test_path}")
-    subprocess.check_call(command)
+    try:
+        subprocess.check_output(command, text=True)
+    except subprocess.CalledProcessError as e:
+        logging.debug(e.output)
+        raise
 
 
 def get_model_test_data(test_import_path):
@@ -82,4 +89,5 @@ if __name__ == '__main__':
    run_tests(c.test_file)
    input, check = get_model_test_data(c.test_import_path)
    test_service(input, check)
+   # Share input with main process:
    print(json.dumps(input))
\ No newline at end of file
